==> jc-1.4.0.tar.gz: java/lang/InternalError.h <==
// public class java.lang.InternalError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 642246d728a60038 java_lang_InternalError
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_VirtualMachineError

#include "java/lang/VirtualMachineError.h"

#ifndef _JC_java_lang_InternalError_H_
#define _JC_java_lang_InternalError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_InternalError$sub_refs	_jc_java_lang_InternalError$sub_refs;
typedef struct _jc_java_lang_InternalError$sub_nonrefs	_jc_java_lang_InternalError$sub_nonrefs;
typedef struct _jc_java_lang_InternalError$refs	_jc_java_lang_InternalError$refs;
typedef struct _jc_java_lang_InternalError$nonrefs	_jc_java_lang_InternalError$nonrefs;
typedef struct _jc_java_lang_InternalError$object	_jc_java_lang_InternalError$object;

typedef struct _jc_java_lang_InternalError$fields_struct	_jc_java_lang_InternalError$fields_struct;
typedef const struct _jc_java_lang_InternalError$vmethods	_jc_java_lang_InternalError$vmethods;
typedef const struct _jc_java_lang_InternalError$vtable	_jc_java_lang_InternalError$vtable;
typedef const struct _jc_java_lang_InternalError$vtype	_jc_java_lang_InternalError$vtype;

// Class fields structure
struct _jc_java_lang_InternalError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_InternalError$fields_struct _jc_java_lang_InternalError$class_fields;

// Constructors
extern void _jc_java_lang_InternalError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_InternalError$object *);
extern void _jc_java_lang_InternalError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_InternalError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_InternalError$vmethods {
};

// Vtable
struct _jc_java_lang_InternalError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
	_jc_java_lang_InternalError$vmethods	java_lang_InternalError;
};

// Vtype
struct _jc_java_lang_InternalError$vtype {
	_jc_type			type;
	_jc_java_lang_InternalError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_InternalError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_InternalError$refs {
    _jc_java_lang_InternalError$sub_refs	java_lang_InternalError;
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_InternalError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_InternalError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
    _jc_java_lang_InternalError$sub_nonrefs	java_lang_InternalError;
};

// Object instance structure
struct _jc_java_lang_InternalError$object {
	_jc_java_lang_InternalError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_InternalError$vtype	*vtype;
	_jc_java_lang_InternalError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_InternalError$vtype _jc_java_lang_InternalError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_InternalError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_InternalError$class_object;

#endif	/* _JC_java_lang_InternalError_H_ */

==> jc-1.4.6.tar.gz: java/lang/InternalError.h <==
// public class java.lang.InternalError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 642246d728a60038 java_lang_InternalError
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_VirtualMachineError

#include "java/lang/VirtualMachineError.h"

#ifndef _JC_java_lang_InternalError_H_
#define _JC_java_lang_InternalError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_InternalError$sub_refs	_jc_java_lang_InternalError$sub_refs;
typedef struct _jc_java_lang_InternalError$sub_nonrefs	_jc_java_lang_InternalError$sub_nonrefs;
typedef struct _jc_java_lang_InternalError$refs	_jc_java_lang_InternalError$refs;
typedef struct _jc_java_lang_InternalError$nonrefs	_jc_java_lang_InternalError$nonrefs;
typedef struct _jc_java_lang_InternalError$object	_jc_java_lang_InternalError$object;

typedef struct _jc_java_lang_InternalError$fields_struct	_jc_java_lang_InternalError$fields_struct;
typedef const struct _jc_java_lang_InternalError$vmethods	_jc_java_lang_InternalError$vmethods;
typedef const struct _jc_java_lang_InternalError$vtable	_jc_java_lang_InternalError$vtable;
typedef const struct _jc_java_lang_InternalError$vtype	_jc_java_lang_InternalError$vtype;

// Class fields structure
struct _jc_java_lang_InternalError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_InternalError$fields_struct _jc_java_lang_InternalError$class_fields;

// Constructors
extern void _jc_java_lang_InternalError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_InternalError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_InternalError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_InternalError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_InternalError$vmethods {
};

// Vtable
struct _jc_java_lang_InternalError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
	_jc_java_lang_InternalError$vmethods	java_lang_InternalError;
};

// Vtype
struct _jc_java_lang_InternalError$vtype {
	_jc_type			type;
	_jc_java_lang_InternalError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_InternalError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_InternalError$refs {
    _jc_java_lang_InternalError$sub_refs	java_lang_InternalError;
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_InternalError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_InternalError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
    _jc_java_lang_InternalError$sub_nonrefs	java_lang_InternalError;
};

// Object instance structure
struct _jc_java_lang_InternalError$object {
	_jc_java_lang_InternalError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_InternalError$vtype	*vtype;
	_jc_java_lang_InternalError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_InternalError$vtype _jc_java_lang_InternalError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_InternalError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_InternalError$class_object;

#endif	/* _JC_java_lang_InternalError_H_ */
